GitCertificateSshRawType enum

The raw SSH host key algorithm.

Inheritance
Available extensions

Values

unknown → const GitCertificateSshRawType

The raw key type is unknown.

rsa → const GitCertificateSshRawType

RSA host key.

dss → const GitCertificateSshRawType

DSS host key.

ecdsa256 → const GitCertificateSshRawType

ECDSA P-256 host key.

ecdsa384 → const GitCertificateSshRawType

ECDSA P-384 host key.

ecdsa521 → const GitCertificateSshRawType

ECDSA P-521 host key.

ed25519 → const GitCertificateSshRawType

Ed25519 host key.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GitCertificateSshRawType>
A constant List of the values in this enum, in order of their declaration.