GitPathGitFile enum

Git-specific file names recognized by libgit2 path checks.

Inheritance
Available extensions

Values

gitignore → const GitPathGitFile

Check for the .gitignore file.

const GitPathGitFile(0)
gitmodules → const GitPathGitFile

Check for the .gitmodules file.

const GitPathGitFile(1)
gitattributes → const GitPathGitFile

Check for the .gitattributes file.

const GitPathGitFile(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GitPathGitFile>
A constant List of the values in this enum, in order of their declaration.