Identity class
Constructors
-
Identity({required String name, required String email})
-
Identity to use for reflogs.
const
Properties
-
email
→ String
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
final
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited