Message class

Utilities for commit message cleanup and trailer parsing.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

prettify({required String message, bool stripComments = false, String commentChar = '#'}) String
Cleans up excess whitespace and ensures the message has a trailing newline.
trailers(String message) Map<String, String>
Parses Git trailers from the final paragraph of message.