RebaseOperation class
A class representing a single operation in a rebase process.
Each operation represents a commit that will be applied during the rebase.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oid → Oid
-
Oid of commit being cherry-picked.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → GitRebaseOperation
-
Type of rebase operation.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited