RepositoryCallback class

Constructors

RepositoryCallback({required String path, bool bare = false, Set<GitRepositoryInit> flags = const {GitRepositoryInit.mkpath}, int mode = 0, String? workdirPath, String? description, String? templatePath, String? initialHead, String? originUrl})
Values used to override the repository creation and customization process during a clone operation.
const

Properties

bare bool
Whether repository is bare.
final
description String?
Description used to initialize the "description" file in the repository.
final
flags Set<GitRepositoryInit>
Combination of GitRepositoryInit flags.
final
hashCode int
The hash code for this object.
no setterinherited
initialHead String?
Name of the head HEAD points at.
final
mode int
Permissions for the repository folder.
final
originUrl String?
"origin" remote URL that will be added after the rest of the repository initialization is completed.
final
path String
Path to the repository.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templatePath String?
Path used for the template directory.
final
workdirPath String?
Path to the working directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited