originUrl property
"origin" remote URL that will be added after the rest of the repository initialization is completed.
Implementation
final String? originUrl;
"origin" remote URL that will be added after the rest of the repository initialization is completed.
final String? originUrl;