hideGlob method

void hideGlob(
  1. String glob
)

Hides matching references.

The OIDs pointed to by the references that match the given glob pattern and their ancestors will be hidden from the output on the revision walk.

A leading "refs/" is implied if not present as well as a trailing "/*" if the glob lacks "?", "*" or "[".

Any references matching this glob which do not point to a committish will be ignored.

Throws a LibGit2Error if an error occurs.

Implementation

void hideGlob(String glob) {
  bindings.hideGlob(walkerPointer: _revWalkPointer, glob: glob);
}