pushGlob method

void pushGlob(
  1. String glob
)

Adds matching references for the traversal.

The OIDs pointed to by the references that match the given glob pattern will be pushed to the revision walker.

A leading "refs/" is implied if not present as well as a trailing "/*" if the glob lacks "?", "*" or "[".

Any references matching this glob which do not point to a committish will be ignored.

Throws a LibGit2Error if an error occurs.

Implementation

void pushGlob(String glob) {
  bindings.pushGlob(walkerPointer: _revWalkPointer, glob: glob);
}