simplifyFirstParent method

void simplifyFirstParent()

Simplify the history by first-parent.

No parents other than the first for each commit will be enqueued. This is useful for viewing the history of a branch without seeing merge commits.

Implementation

void simplifyFirstParent() => bindings.simplifyFirstParent(_revWalkPointer);