GitCertificateHostkey class
SSH host key information presented by a remote.
The object is only valid while the certificate callback is executing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMd5 → bool
-
Whether md5 is available.
no setter
- hasRawHostkey → bool
-
Whether rawHostkey and rawType are available.
no setter
- hasSha1 → bool
-
Whether sha1 is available.
no setter
- hasSha256 → bool
-
Whether sha256 is available.
no setter
- md5 → Uint8List?
-
MD5 host key hash, or
nullwhen unavailable.no setter - rawHostkey → Uint8List?
-
Raw SSH host key bytes, or
nullwhen unavailable.no setter - rawType → GitCertificateSshRawType
-
Raw SSH host key algorithm.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha1 → Uint8List?
-
SHA-1 host key hash, or
nullwhen unavailable.no setter - sha256 → Uint8List?
-
SHA-256 host key hash, or
nullwhen unavailable.no setter - typeFlags → int
-
Raw bitmask of available SSH host key fields.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited