GitObject enum
Basic type (loose or packed) of any Git object.
Values
- any → const GitObject
-
Object can be any of the following.
const GitObject(-2) - invalid → const GitObject
-
Object is invalid.
const GitObject(-1) - commit → const GitObject
-
A commit object.
const GitObject(1) - tree → const GitObject
-
A tree (directory listing) object.
const GitObject(2) - blob → const GitObject
-
A file revision object.
const GitObject(3) - tag → const GitObject
-
An annotated tag object.
const GitObject(4) - offsetDelta → const GitObject
-
A delta, base is given by an offset.
const GitObject(6) - refDelta → const GitObject
-
A delta, base is given by object id.
const GitObject(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited